// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter;

import java.sql.Connection;
import java.sql.SQLException;

import javax.naming.NamingException;
import javax.sql.DataSource;

import com.ibm.wbimonitor.samples.db2emitter.exception.EventRetrieveFailedException;

/*
 * Retrieves the detail dat
 */
public abstract class AbstractEventRetriever implements EventRetriever {

    private static DataSource dataSource = null;

    protected Connection connection = null;

    public AbstractEventRetriever( ) throws EventRetrieveFailedException {
        try {
            if( dataSource == null )
                dataSource = DB2Helper.getDataSource( );

            connection = dataSource.getConnection( );
        }
        catch( NamingException ne ) {
            throw new EventRetrieveFailedException( "Unable to obtain the datasource for the database.", ne );
        }
        catch( SQLException se ) {
            throw new EventRetrieveFailedException( "Unable to get a connection to the database.", se );
        }
    }

    /*
     * Release the connection.
     */
    public void close( ) {
        if( connection == null ) {
            return;
        }
        try {
            connection.close( );
            connection = null;
        }
        catch( SQLException e ) {
            throw new Error( "", e );
        }
    }

    /*
     * User implements data retrieval logic.
     */
    public abstract Object retrieve( Object o ) throws EventRetrieveFailedException;

}