// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.db2emitter.formatter;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.eclipse.hyades.logging.events.cbe.CommonBaseEvent;
import org.eclipse.hyades.logging.events.cbe.ComponentIdentification;
import org.eclipse.hyades.logging.events.cbe.EventFactory;
import org.eclipse.hyades.logging.events.cbe.EventFactoryFactory;
import org.eclipse.hyades.logging.events.cbe.ExtendedDataElement;
import org.eclipse.hyades.logging.events.cbe.Situation;

import com.ibm.wbimonitor.samples.db2emitter.EventTableBean;
import com.ibm.wbimonitor.samples.db2emitter.exception.EventRetrieveFailedException;
import com.ibm.wbimonitor.samples.db2emitter.retriever.CUSTOMEREventRetrieverImpl;
import com.ibm.wbimonitor.samples.emitterframework.EventFormatter;
import com.ibm.wbimonitor.samples.emitterframework.exception.EventFormatFailedException;

/*
 * This class implements the EventFormatter interface.
 */
public class CUSTOMERFormatterImpl implements EventFormatter {

    /*
     * This method implements the format interface of EventFormatter.
     */
    public CommonBaseEvent format( Object o ) throws EventFormatFailedException {
        Object retrieved = null;
        CUSTOMEREventRetrieverImpl retriever = null;
        CommonBaseEvent event = null;
        try {
            retriever = new CUSTOMEREventRetrieverImpl( );
            retrieved = retriever.retrieve( o );

            EventFactory eventFactory = (EventFactory)EventFactoryFactory.createEventFactory( );
            event = eventFactory.createCommonBaseEvent( );

            event.setVersion( "1.0.1" );
            event.setCreationTimeAsLong( System.currentTimeMillis( ) );

            ComponentIdentification componentId = eventFactory.createComponentIdentification( );
            componentId.setApplication( "DB2" );
            componentId.setComponent( "db2.exe" );
            componentId.setSubComponent( "db2syscs.exe" );
            componentId.setComponentType( "http://www.ibm.com/namespaces/db2" );
            componentId.setComponentIdType( "db2syscs.exe" );
            componentId.setLocation( "lycos" );
            componentId.setLocationType( "IPV4" );
            event.setSourceComponentId( componentId );

            Situation situation = eventFactory.createSituation( );
            situation.setAvailableSituation( "EXTERNAL", "NOT AVAILABLE", "STARTABLE", "FUNCTION_PROCESS" );
            event.setSituation( situation );

            ExtendedDataElement trig = event.addExtendedDataElement( "TRIGGER" );
            switch( ( (EventTableBean)o ).getTrigger( ) ) {
                case 'C':
                    trig.setValuesAsString( "CREATE" );
                    break;
                case 'U':
                    trig.setValuesAsString( "UPDATE" );
                    break;
                case 'D':
                    trig.setValuesAsString( "DELETE" );
                    break;
            }

            if( retrieved instanceof String ) {
                ExtendedDataElement id = event.addExtendedDataElement( "ID" );
                id.setValuesAsInt( Integer.parseInt( (String)retrieved ) );
            }
            else {
                ExtendedDataElement id = event.addExtendedDataElement( "ID" );
                id.setValuesAsInt( ( (ResultSet)retrieved ).getInt( "ID" ) );
                ExtendedDataElement name = event.addExtendedDataElement( "NAME" );
                name.setValuesAsString( ( (ResultSet)retrieved ).getString( "NAME" ) );
                ExtendedDataElement address = event.addExtendedDataElement( "ADDRESS" );
                address.setValuesAsString( ( (ResultSet)retrieved ).getString( "ADDRESS" ) );
                ExtendedDataElement tel = event.addExtendedDataElement( "TEL" );
                tel.setValuesAsString( ( (ResultSet)retrieved ).getString( "TEL" ) );
                ExtendedDataElement email = event.addExtendedDataElement( "EMAIL" );
                email.setValuesAsString( ( (ResultSet)retrieved ).getString( "EMAIL" ) );
            }
        }
        catch( EventRetrieveFailedException e ) {
            throw new EventFormatFailedException( "Cannot retrieve from the customer table.", e );
        }
        catch( SQLException e ) {
            throw new EventFormatFailedException( "Cannot retrieve from the customer table.", e );
        }
        finally {
            retriever.close( );
        }

        return event;
    }
}