// ===================================================================
// (C) Copyright IBM Corp. 2005, 2006 All Rights Reserved.
//                                                                           
// Licensed Materials - Property of IBM
//                                                          
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.
//              
// You may copy, modify, and distribute this sample program in any
// form without payment to IBM, for any purpose including developing,
// using, marketing or distributing programs that include or are
// derivative works of the sample program.
//                                                                           
// The sample program is provided to you on an "AS IS" basis, without
// warranty of any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES,
// EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Some jurisdictions do not allow for the exclusion or limitation of
// implied warranties, so the above limitations or exclusions may not
// apply to you. IBM shall not be liable for any damages you suffer as
// a result of using, modifying or distributing the sample program or
// its derivatives.
//===================================================================
package com.ibm.wbimonitor.samples.fileemitter;

import java.util.Properties;

public class EventFileBean implements Comparable {

    /*
     * The canonical path of the event file.
     */
    private String canonicalPath;

    /*
     * The date the event file was last modified. This field is used for sorting
     * purposes in order to process the events in a FIFO manner.
     */
    private long lastModifiedDate;

    /*
     * The file contents.
     */
    private Properties fileContents;

    public EventFileBean( ) {
        this.canonicalPath = new String( );
        this.lastModifiedDate = 0;
    }

    public EventFileBean( String canonicalPath, long lastModifiedDate ) {
        this.canonicalPath = canonicalPath;
        this.lastModifiedDate = lastModifiedDate;
    }

    public String getCanonicalPath( ) {
        return this.canonicalPath;
    }

    public void setCanonicalPath( String canonicalPath ) {
        this.canonicalPath = canonicalPath;
    }

    public long getLastModifiedDate( ) {
        return this.lastModifiedDate;
    }

    public void setLastModifiedDate( long lastModifiedDate ) {
        this.lastModifiedDate = lastModifiedDate;
    }

    public Properties getFileContents( ) {
        return this.fileContents;
    }

    public void setFileContents( Properties fileContents ) {
        this.fileContents = fileContents;
    }

    /*
     * This method implements the compareTo interface defined in Comparable. The
     * comparison is done based on the lastModifiedDate in order to sort the
     * event files by creation time and allow processing of these events in a
     * FIFO manner.
     */
    public int compareTo( Object o ) {
        if( !( o instanceof EventFileBean ) )
            throw new ClassCastException( "Object types are incompatible. Unable to perform comparison." );

        return ( ( new Long( this.lastModifiedDate ) ).compareTo( new Long( ( (EventFileBean)o ).getLastModifiedDate( ) ) ) );
    }

}